@@ -7,7 +7,7 @@
  */
 
 /*
- * Copyright (C) 2003,2004,2005,2006,2007  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2013  Enrico Zini <enrico@debian.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <wibble/sys/fs.h>
 #include <string>
+#include <wibble/sys/fs.h>
 
 namespace ept {
 namespace debtags {
@@ -45,7 +45,8 @@ protected:
 	FileType fileType(const std::string& name);
 
 public:
-	SourceDir(const std::string& path) : Directory(path) {}
+    SourceDir(const std::string& path);
+    ~SourceDir();
 
 	/// Return the time of the newest file in the source directory
 	time_t timestamp();
